
# Slot: method_name


Name of the node embedding method.

URI: [https://w3id.org/neat/nodeEmbeddingsParams__method_name](https://w3id.org/neat/nodeEmbeddingsParams__method_name)


## Domain and Range

None &#8594;  <sub>0..1</sub> [node_embed_method_enum](node_embed_method_enum.md)

## Parents


## Children


## Used by

 * [NodeEmbeddingsParams](NodeEmbeddingsParams.md)
